@@ -41,6 +41,10 @@ class Orden(BaseModel):
     op_cuenta_ben: str = None
     op_rfc_curp_ben: str = None
     op_ins_clave_ben: digits(3, 5) = None
+    # participant info
+    op_cuenta_participante_ord: str = None
+    op_nom_participante_ord: str = None
+    op_rfc_participante_ord: str = None
     # additional destination info
     op_nom_ben_2: str = None
     op_tc_clave_ben_2: types.TipoCuentaOrdenPago = None
@@ -102,6 +106,11 @@ class Orden(BaseModel):
     class Config:  # noqa: WPS306, WPS431
         use_enum_values = True
 
+    @validator('op_monto', always=True)
+    def set_amount(cls, value):  # noqa: WPS110, N805
+        amount = float(value)
+        return '{amount:.2f}'.format(amount=amount)
+
     @validator('op_fecha_oper')
     def op_fecha_oper_must_be_iso_format(cls, value):  # noqa: WPS110, N805
         regex = re.compile(r'^\d{4}(0[1-9]|1[0-2])(0[1-9]|[12][0-9]|3[01])$')
